ReturnCode_t — Spec 5.2.1.
Enums
- Return
Code ReturnCode_t(spec 5.2.1.1-5.2.1.6, p. 9-10) — status codes for all RTC operations that do not by nature return another value.
ReturnCode_t — Spec 5.2.1.
ReturnCode_t (spec 5.2.1.1-5.2.1.6, p. 9-10) — status codes
for all RTC operations that do not by nature return another
value.